//-------------------------------------------------------------------------------
// DBMenu
//-------------------------------------------------------------------------------

datablock StaticShapeData(DBMenu : DBObject)
{
   // The category variable determines where the item
   // shows up in the mission editor's creator tree.
   // Path is relative to where the script is executed from.
   category = "Restaurant";
   shapeFile = "~/data/shapes/restaurant/menu/menu.dts";
   bitmap = "";
   soundPutDown = "~/data/sound/cogmac/pages.wav";
   noun = "menu";
};

function DBMenu::OnPutDown( %this, %client, %user, %obj, %surface, %pos, %ignore )
{
   COGLOG_STATECHANGE( %client.player, "ATPOS", COGLOG_POS(%client.player.getPosition()) );

   // Play a putdown sound.
   PlaySound( %this.soundPutDown, %user.getPosition() );

   CommandToClient( %client, 'CleanupPopup' );

   // Delete menus when returned to the menu box.
   if( ( %surface.getDatablock().getName() $= "DBMenuBox" ) || ( %surface.getDatablock().getName() $= "DBPodium" ) )
   {
      COGLOG_STATECHANGE( %obj, "ON", COGLOG_ID(%surface) );
      COGLOG_STATECHANGE( %obj, "DELETED", "TRUE" );
      %obj.delete();
      return;
   }

   DBObject::OnPutDown( %this, %client, %user, %obj, %surface, %pos, %ignore ); 
}

function DBMenu::OnLookAt( %this, %client, %obj )
{
   COGLOG_STATECHANGE( %client.player, "ATPOS", COGLOG_POS(%client.player.getPosition()) );
   COGLOG_ACTION( %client.player, "LOOKAT", %obj );
   CommandToClient( %client, 'ShowMenuGui' );
}

function DBMenu::onAdd(%this, %obj) { DBObject::OnAdd(%this, %obj); }
function DBMenu::OnTouch( %this, %client, %user, %obj ) { DBMenu::OnLookAt( %this, %client, %obj ); }
function DBMenu::OnPickup( %this, %client, %user, %obj ) { DBObject::OnPickup( %this, %client, %user, %obj ); }
function DBMenu::OnGive( %this, %client, %user, %obj, %target, %pos ) { DBObject::OnGive( %this, %client, %user, %obj, %target, %pos ); }
function DBMenu::OnSit( %this, %client, %user, %obj ) { DBObject::OnSit( %this, %client, %user, %obj ); }
function DBMenu::OnEat( %this, %client, %obj ) { DBObject::OnEat( %this, %client, %obj ); }


//-------------------------------------------------------------------------------
// DBMenuBox
//-------------------------------------------------------------------------------

datablock StaticShapeData(DBMenuBox : DBObject)
{
   // The category variable determines where the item
   // shows up in the mission editor's creator tree.
   // Path is relative to where the script is executed from.
   category = "Restaurant";
   shapeFile = "~/data/shapes/restaurant/menu/menubox.dts";
   bitmap = "";
   noun = "podium";
};

function DBMenuBox::OnPickup( %this, %client, %user, %obj )
{
   COGLOG_STATECHANGE( %client.player, "ATPOS", COGLOG_POS(%client.player.getPosition()) );

   // Spawn a menu.
   %menu = new StaticShape() {
      dataBlock = DBMenu;
   };

   // Drop anything we were already carrying.
   %mounted = %user.getMountedObject( 0 );   
   if( %mounted > 0 )
   {
      // Drop on a surface.
      %pos = %obj.getTransform();
      %mounted.getDataBlock().OnPutDown( %client, %user, %mounted, %obj, %pos, %obj );
   }

   // Pick up the menu (not the box).
   DBObject::OnPickup( %this, %client, %user, %menu );
}

function DBMenuBox::OnLookAt( %this, %client, %obj )
{
   COGLOG_STATECHANGE( %client.player, "ATPOS", COGLOG_POS(%client.player.getPosition()) );
   COGLOG_ACTION( %client.player, "LOOKAT", %obj );
   CommandToClient( %client, 'ShowMenuGui' );
}

function DBMenuBox::onAdd(%this, %obj) { DBObject::OnAdd(%this, %obj); }
function DBMenuBox::OnTouch( %this, %client, %user, %obj ) { DBMenuBox::OnLookAt( %this, %client, %obj ); }
function DBMenuBox::OnEat( %this, %client, %obj ) { DBObject::OnEat( %this, %client, %obj ); }
function DBMenuBox::OnGive( %this, %client, %user, %obj, %target, %pos ) { DBObject::OnGive( %this, %client, %user, %obj, %target, %pos ); }









